@@ -47,11 +47,10 @@ private:
     /* Shows the details of a resource
      *
      */
-    void showDetails(const KLDAPCore::LdapObject &, const KLDAPWidgets::LdapClient &client);
+    INCIDENCEEDITOR_NO_EXPORT void showDetails(const KLDAPCore::LdapObject &, const KLDAPWidgets::LdapClient &client);
 
     QItemSelectionModel *selectionModel = nullptr;
 
-private:
     /* A new searchString is entered
      *
      */
@@ -69,7 +68,6 @@ private:
 
     INCIDENCEEDITOR_NO_EXPORT void slotLayoutChanged();
 
-private:
     INCIDENCEEDITOR_NO_EXPORT void readConfig();
     INCIDENCEEDITOR_NO_EXPORT void writeConfig();
     CalendarSupport::FreeBusyItemModel *mModel = nullptr;
